(* $Id: test_ppm13.ml,v 1.6 2014/02/27 16:36:36 fclement Exp $ *)

(* essai2.ml : shows what can be done using graphics and graphps. *)

open Ugraphics;;
open Unatural;;

let sc = 5.0;;

let round f = Unatural.natural_of_float (f +. 0.5);;

let scale l = sc *. l;;
let scale_int l = round (scale l);;

let szx = scale_int 100.
and szy = scale_int 100.;;

let string_of_natural n = string_of_int (Unatural.int_of_natural n);;

Graphics.open_graph
 (Printf.sprintf " %sx%s" (string_of_natural szx) (string_of_natural szy));;

let fill_rect x y w h =
  let x = scale_int x
  and y = scale_int y
  and w = scale_int w
  and h = scale_int h in
  fill_rect x y w h
;;

let grad_ellipse gm x y w h =
  let x = scale_int x
  and y = scale_int y
  and w = scale_int w
  and h = scale_int h in
  Gradient.grad_ellipse gm x y w h
;;

let grad_ellipse_hor c1 c2 =
  grad_ellipse (Gradient.Ellipse_Horizontal (c1, c2))
and grad_ellipse_ver c1 c2 =
  grad_ellipse (Gradient.Ellipse_Vertical (c1, c2))
and grad_ellipse_diag1 c1 c2 =
  grad_ellipse (Gradient.Ellipse_Diagonal1 (c1, c2))
and grad_ellipse_diag2 c1 c2 =
  grad_ellipse (Gradient.Ellipse_Diagonal2 (c1, c2))
and grad_ellipse_radrect c1 c2 xc yc rat =
  let xc = scale_int xc
  and yc = scale_int yc in
  let rat = aspect_ratio_of_int_pair rat in
  grad_ellipse (Gradient.Ellipse_Radial_Rectangular (c1, c2, xc, yc, rat))
and grad_ellipse_radell c1 c2 xc yc rat =
  let xc = scale_int xc
  and yc = scale_int yc in
  let rat = aspect_ratio_of_int_pair rat in
  grad_ellipse (Gradient.Ellipse_Radial_Elliptic (c1, c2, xc, yc, rat))
;;

(* Background. *)
set_color white;;
fill_rect 0. 0. (float_of_natural szx) (float_of_natural szy);;

(* An ellipse with horizontal gradient. *)
grad_ellipse_hor red green 5. 65. 40. 30.;;

(* An ellipse with vertical gradient. *)
grad_ellipse_ver yellow blue 50. 75. 45. 20.;;

(* An ellipse with diagonal1 gradient. *)
grad_ellipse_diag1 black magenta 50. 50. 20. 20.;;

(* An ellipse with diagonal2 gradient. *)
grad_ellipse_diag2 cyan black 75. 50. 20. 20.;;

(* An ellipse with rectangular gradient. *)
grad_ellipse_radrect white blue 20. 30. (2, 3) 5. 5. 40. 55.;;

(* An ellipse with elliptic gradient. *)
grad_ellipse_radell white black 75. 20. (3, 2) 50. 5. 45. 40.;;

Grimage.save_screen_ppm "test13.ppm";;

Graphics.wait_next_event [Graphics.Key_pressed];;

